@@ -3,7 +3,7 @@
 
 PrepareWriteR = function(Author=getOption("BrailleR.Author")){
 if(interactive()){
-if(version$arch %in% c("i386", "x64")){
+if(.Platform$OS.type=="windows"){
 RHome= gsub("/", "\\\\\\\\", Sys.getenv("R_HOME"))
 MyHome = gsub("/", "\\\\\\\\", gsub("\\\\", "/", Sys.getenv("HOME")))
 
@@ -17,11 +17,11 @@ cat(paste0('{
 }
 '), file='WriteR.init')
 
-cat("The settings file for WriteR has been created.\n")
+message("The settings file for WriteR has been created.")
 
 file.copy(paste0(system.file(package="BrailleR"), "/Python/Writer/", c("WriteR.pyw", "HelpPage.html", "HelpPage.Rmd", "Basics.Rmd")), ".")
-cat("Copies of the main wxPython script and help page documents have been copied \ninto your working directory.\n")
-cat("You can move these files to your preferred folder for WriteR, \nor start working here.\n")
+message("Copies of the main wxPython script and help page documents have been copied \ninto your working directory.")
+message("You can move these files to your preferred folder for WriteR, \nor start working here.")
 }
 else{warning("This function is for users running R under the Windows operating system.\n")}
 }
